@@ -27,8 +27,10 @@ import datetime		# required for .timedelta()
 import sys			# required for .stdout.write()
 from math import cos as cos
 from math import copysign as copysign
+
 # Third party imports
 import ephem
+
 # Local application imports
 from skyalmanac.lib import alma_skyfield as alma_skyfield
 from skyalmanac.lib import alma_ephem as alma_ephem
@@ -865,10 +867,12 @@ def twilighttab(date, dfcm):
 def lunatikz(phase, dfcm):
     # argument: moon phase (0:new to π:full to 2π:new)
     # returns the code for a moon image overlaid with a shadow (pardon the function name)
-    radius = 0.375  # moon image radius (cm)
-    diam   = 0.75   # moon image diameter (cm)
-    top    = diam   # top of moon (cm)
-    bottom = 0.0    # bottom of moon (cm)
+    f      = 0.01     # empirical fudge factor to position moon's shadow exactly over image
+    radius = 0.375    # moon image radius (cm)
+    xstart = radius + f
+    diam   = 0.75     # moon image diameter (cm)
+    top    = diam + f # top of moon (cm)
+    bottom = 0.0 + f  # bottom of moon (cm)
     if phase < ephem.pi*0.5:    # new moon to 1st quarter
         ystart = top
         fr_angle = 90           # trace a semicircle anticlockwise from top to bottom
@@ -902,9 +906,9 @@ def lunatikz(phase, dfcm):
     tikz = r'''\multicolumn{{1}}{{|c|}}{{\multirow{{3}}{{*}}
 {{\begin{{tikzpicture}}
 \node[anchor=south west,inner sep=0] at (0,0) {{\includegraphics[width=0.75cm]{{{}}}}};
-\path [fill=darknight, opacity=0.75] (0.375,{:5.3f}) arc [x radius=0.375, y radius=0.375, start angle={:d}, end angle={:d}]  arc [x radius={:f}, y radius=0.375, start angle={:d}, end angle={:d}];
+\path [fill=darknight, opacity=0.75] ({:5.3f},{:5.3f}) arc [x radius=0.375, y radius=0.375, start angle={:d}, end angle={:d}]  arc [x radius={:f}, y radius=0.375, start angle={:d}, end angle={:d}];
 \end{{tikzpicture}}}}}}\\
-'''.format(dfcm, ystart, fr_angle, to_angle, xradius, ret_angle, end_angle)
+'''.format(dfcm, xstart, ystart, fr_angle, to_angle, xradius, ret_angle, end_angle)
     return tikz
 
 
@@ -920,12 +924,16 @@ def double_events_found(m1, m2):
 def doublepage(date, page1, dfcm):
     # creates a doublepage (3 days) of the nautical almanac
 
+    # time delta values for the initial date&time...
+    dut1, deltat = alma_skyfield.getParams(date)
+    timedelta = r"DUT1 = UT1-UTC = {:+.4f} sec\quad$\Delta$T = TT-UT1 = {:+.4f} sec".format(dut1, deltat)
+
     alma_skyfield.find_new_moon(date)
     #import alma_skyfield
-    #print("previous  new moon: {}".fotmat(alma_skyfield.PreviousNewMoon))
-    #print("previous full moon: {}".fotmat(alma_skyfield.PreviousFullMoon))
-    #print("next      new moon: {}".fotmat(alma_skyfield.NextNewMoon))
-    #print("next     full moon: {}".fotmat(alma_skyfield.NextFullMoon))
+    #print("previous  new moon: {}".format(alma_skyfield.PreviousNewMoon))
+    #print("previous full moon: {}".format(alma_skyfield.PreviousFullMoon))
+    #print("next      new moon: {}".format(alma_skyfield.NextNewMoon))
+    #print("next     full moon: {}".format(alma_skyfield.NextFullMoon))
 
     page = ''
     if not(page1):
@@ -942,7 +950,7 @@ def doublepage(date, page1, dfcm):
     page = page + r'''
 \sffamily
 \noindent
-{}\textbf{{{}, {}, {}   ({}.,  {}.,  {}.)}}'''.format(leftindent,date.strftime("%B %d"),(date+datetime.timedelta(days=1)).strftime("%d"),(date+datetime.timedelta(days=2)).strftime("%d"),date.strftime("%a"),(date+datetime.timedelta(days=1)).strftime("%a"),(date+datetime.timedelta(days=2)).strftime("%a"))
+{}\textbf{{{}, {}, {} UT ({}.,  {}.,  {}.)}}'''.format(leftindent,date.strftime("%B %d"),(date+datetime.timedelta(days=1)).strftime("%d"),(date+datetime.timedelta(days=2)).strftime("%d"),date.strftime("%a"),(date+datetime.timedelta(days=1)).strftime("%a"),(date+datetime.timedelta(days=2)).strftime("%a"))
 
     if config.tbls == "m":
         page = page + r'\par'
@@ -963,11 +971,11 @@ def doublepage(date, page1, dfcm):
 \end{{scriptsize}}
 % ------------------ N E W   P A G E ------------------
 \newpage
-\begin{{flushright}}
-\textbf{{{} to {}}}{}%
-\end{{flushright}}\par
+\begin{{flushleft}}     % required so that \par works
+{{\footnotesize {}}}\hfill\textbf{{{} to {} UT}}
+\end{{flushleft}}\par
 \begin{{scriptsize}}
-'''.format(date.strftime("%Y %B %d"),(date+datetime.timedelta(days=2)).strftime("%b. %d"),rightindent)
+'''.format(timedelta, date.strftime("%Y %B %d"),(date+datetime.timedelta(days=2)).strftime("%b. %d"),rightindent)
     page = page + str1
     if config.tbls == "m":
         page = page + sunmoontabm(date)
@@ -1007,7 +1015,8 @@ def pages(first_day, p, dfcm):
 
 
 def almanac(first_day, pagenum, df180, df360, dfcm):
-    # make almanac from date till date
+
+    # make almanac starting from first_day
     year = first_day.year
     mth = first_day.month
     day = first_day.day
@@ -1023,8 +1032,8 @@ def almanac(first_day, pagenum, df180, df360, dfcm):
         rm1 = "10mm"
         tm = "21mm"     # data pages...
         bm = "18mm"
-        lm = "12mm"
-        rm = "8mm"
+        lm = "10.5mm"
+        rm = "9mm"
         if config.tbls == "m":
             tm = "10mm"
             bm = "15mm"
@@ -1093,7 +1102,7 @@ def almanac(first_day, pagenum, df180, df360, dfcm):
     alm = alm + r'''
     \begin{{titlepage}}
     \begin{{center}}
-    \textsc{{\Large Generated using PyEphem and Skyfield}}\\
+    \textsc{{\Large Generated using Ephem and Skyfield}}\\
     \large http://rhodesmill.org/skyfield/\\[0.7cm]
     % TRIM values: left bottom right top
     \includegraphics[clip, trim=12mm 20cm 12mm 21mm, width=0.92\textwidth]{{{}}}\\[0.3cm]
